# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 窗口
# @Time   : 2024-09-19 16:42
# @Author : 毛鹏
from .mango_diglog import MangoDialog
from .mango_tooltip_box import show_info_message, show_failed_message, show_warning_message, show_success_message
from .mango_window import MangoWindow



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-18 11:11
# @Author : 毛鹏
from mango_ui.init import *


class MangoTextEdit(QTextEdit):
    clicked = Signal(object)

    def __init__(
            self,
            placeholder,
            value,
            theme=THEME
    ):
        super().__init__()
        self.value = value
        self.theme = theme.model_dump()

        if placeholder:
            self.setPlaceholderText(placeholder)
        self.set_stylesheet(self.theme)

    def set_stylesheet(self, theme):
        style = f"""
        QTextEdit {{
        	background-color: {theme['white']};
        	border-radius: {theme['radius']}px;
        	border: {theme['border_size']}px solid gray;
        	padding-left: 10px;
            padding-right: 10px;
        	selection-color: {theme['white']};
        	selection-background-color: {theme['context_color']};
            color: {theme['text_foreground']};
        }}

        QTextEdit:focus {{
        	border: {theme['border_size']}px solid {theme['context_color']};
            background-color: {theme['dark_three']};
        }}
        """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *
from mango_ui.widgets.menu.mango_left_column.mango_icon import MangoIcon
from mango_ui.widgets.menu.mango_left_column.mango_left_button import MangoLeftButton
from mango_ui.widgets.menu.mango_left_column.ui_left_column import LeftColumn


class MangoLeftColumn(QWidget):
    clicked = Signal(object)
    released = Signal(object)

    def __init__(
            self,
            parent,
            app_parent,
            text_title,
            text_title_size=THEME.font.title_size,
            text_title_color=THEME.text_foreground,
            dark_one=THEME.dark_one,
            bg_color=THEME.bg_three,
            btn_color=THEME.bg_three,
            btn_color_hover=THEME.bg_two,
            btn_color_pressed=THEME.bg_one,
            icon_path=":/icons/settings.svg",
            icon_color=THEME.icon_color,
            icon_color_hover=THEME.icon_hover,
            icon_color_pressed=THEME.icon_pressed,
            context_color=THEME.context_color,
            icon_close_path=":/icons/icon_close.svg",
            radius=8
    ):
        super().__init__()

        self._parent = parent
        self._app_parent = app_parent
        self._text_title = text_title
        self._text_title_size = text_title_size
        self._text_title_color = text_title_color
        self._icon_path = icon_path
        self._dark_one = dark_one
        self._bg_color = bg_color
        self._btn_color = btn_color
        self._btn_color_hover = btn_color_hover
        self._btn_color_pressed = btn_color_pressed
        self._icon_color = icon_color
        self._icon_color_hover = icon_color_hover
        self._icon_color_pressed = icon_color_pressed
        self._context_color = context_color
        self._icon_close_path = icon_close_path
        self._radius = radius

        self.setup_ui()

        # 在BG框架中添加左列
        self.menus = LeftColumn()
        self.menus.setup_ui(self.content_frame)

    # 标题左列发出信号
    def btn_clicked(self):
        self.clicked.emit(self.btn_close)

    def btn_released(self):
        self.released.emit(self.btn_close)

    # 小部件

    def setup_ui(self):
        # 基础布局
        self.base_layout = QVBoxLayout(self)
        self.base_layout.setContentsMargins(0, 0, 0, 0)
        self.base_layout.setSpacing(0)

        # 标题框架

        self.title_frame = QFrame()
        self.title_frame.setMaximumHeight(47)
        self.title_frame.setMinimumHeight(47)

        # 标题库布局
        self.title_base_layout = QVBoxLayout(self.title_frame)
        self.title_base_layout.setContentsMargins(5, 3, 5, 3)

        # 标题BG
        self.title_bg_frame = QFrame()
        self.title_bg_frame.setObjectName("title_bg_frame")
        self.title_bg_frame.setStyleSheet(f'''
        #title_bg_frame {{
            background-color: {self._bg_color};
            border-radius: {self._radius}px;
        }}
        ''')

        # 布局标题BG
        self.title_bg_layout = QHBoxLayout(self.title_bg_frame)
        self.title_bg_layout.setContentsMargins(5, 5, 5, 5)
        self.title_bg_layout.setSpacing(3)

        # ICON
        self.icon_frame = QFrame()
        self.icon_frame.setFixedSize(30, 30)
        self.icon_frame.setStyleSheet("background: none;")
        self.icon_layout = QVBoxLayout(self.icon_frame)
        self.icon_layout.setContentsMargins(0, 0, 0, 0)
        self.icon_layout.setSpacing(5)
        self.icon = MangoIcon(self._icon_path, self._icon_color)
        self.icon_layout.addWidget(self.icon, Qt.AlignCenter, Qt.AlignCenter)

        # 标签
        self.title_label = QLabel(self._text_title)
        self.title_label.setObjectName("title_label")
        self.title_label.setStyleSheet(f'''
        #title_label {{
            font-size: {self._text_title_size}pt;
            color: {self._text_title_color};
            padding-bottom: 2px;
            background: none;
        }}
        ''')

        # BTN帧
        self.btn_frame = QFrame()
        self.btn_frame.setFixedSize(30, 30)
        self.btn_frame.setStyleSheet("background: none;")
        # 关闭按钮
        self.btn_close = MangoLeftButton(
            self._parent,
            self._app_parent,
            tooltip_text="Hide",
            dark_one=self._dark_one,
            bg_color=self._btn_color,
            bg_color_hover=self._btn_color_hover,
            bg_color_pressed=self._btn_color_pressed,
            icon_color=self._icon_color,
            icon_color_hover=self._icon_color_hover,
            icon_color_pressed=self._icon_color_pressed,
            icon_color_active=self._icon_color_pressed,
            context_color=self._context_color,
            text_foreground=self._text_title_color,
            icon_path=self._icon_close_path,
            radius=6,
        )
        self.btn_close.setParent(self.btn_frame)
        self.btn_close.setObjectName("btn_close_left_column")

        # 添加到标题布局
        self.title_bg_layout.addWidget(self.icon_frame)
        self.title_bg_layout.addWidget(self.title_label)
        self.title_bg_layout.addWidget(self.btn_frame)

        # 将标题BG添加到布局中
        self.title_base_layout.addWidget(self.title_bg_frame)

        # 内容框架
        self.content_frame = QFrame()
        self.content_frame.setStyleSheet("background: none")

        # 添加到布局

        self.base_layout.addWidget(self.title_frame)
        self.base_layout.addWidget(self.content_frame)

        self.btn_close.clicked.connect(self.btn_clicked)
        self.btn_close.released.connect(self.btn_released)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoLeftButton(QPushButton):
    def __init__(
            self,
            parent,
            app_parent=None,
            tooltip_text="",
            btn_id=None,
            width=30,
            height=30,
            radius=8,
            bg_color="#343b48",
            bg_color_hover="#3c4454",
            bg_color_pressed="#2c313c",
            icon_color="#c3ccdf",
            icon_color_hover="#dce1ec",
            icon_color_pressed="#edf0f5",
            icon_color_active="#f5f6f9",
            icon_path="",
            dark_one="#1b1e23",
            context_color="#568af2",
            text_foreground="#8a95aa",
            is_active=False
    ):
        super().__init__()

        self.setFixedSize(width, height)
        self.setCursor(Qt.PointingHandCursor)
        self.setObjectName(btn_id)

        self._bg_color = bg_color
        self._bg_color_hover = bg_color_hover
        self._bg_color_pressed = bg_color_pressed
        self._icon_color = icon_color
        self._icon_color_hover = icon_color_hover
        self._icon_color_pressed = icon_color_pressed
        self._icon_color_active = icon_color_active
        self._context_color = context_color
        self._top_margin = self.height() + 6
        self._is_active = is_active
        self._set_bg_color = bg_color
        self._set_icon_path = icon_path
        self._set_icon_color = icon_color
        self._set_border_radius = radius
        self._parent = parent
        self._app_parent = app_parent

        self._tooltip_text = tooltip_text
        self._tooltip = _ToolTip(
            app_parent,
            tooltip_text,
            dark_one,
            context_color,
            text_foreground
        )
        self._tooltip.hide()

    # 设置活动菜单
    def set_active(self, is_active):
        self._is_active = is_active
        self.repaint()

    # 如果是活动菜单，则返回
    def is_active(self):
        return self._is_active

    # 绘制按钮和图标
    def paintEvent(self, event):
        paint = QPainter()
        paint.begin(self)
        paint.setRenderHint(QPainter.RenderHint.Antialiasing)

        if self._is_active:
            brush = QBrush(QColor(self._bg_color_pressed))
        else:
            brush = QBrush(QColor(self._set_bg_color))

        # 创建矩形
        rect = QRect(0, 0, self.width(), self.height())
        paint.setPen(Qt.NoPen)
        paint.setBrush(brush)
        paint.drawRoundedRect(
            rect,
            self._set_border_radius,
            self._set_border_radius
        )

        # 绘制图标
        self.icon_paint(paint, self._set_icon_path, rect)

        # 末端油漆工
        paint.end()

    # 更新样式
    def change_style(self, event):
        if event == QEvent.Enter:
            self._set_bg_color = self._bg_color_hover
            self._set_icon_color = self._icon_color_hover
            self.repaint()
        elif event == QEvent.Leave:
            self._set_bg_color = self._bg_color
            self._set_icon_color = self._icon_color
            self.repaint()
        elif event == QEvent.MouseButtonPress:
            self._set_bg_color = self._bg_color_pressed
            self._set_icon_color = self._icon_color_pressed
            self.repaint()
        elif event == QEvent.MouseButtonRelease:
            self._set_bg_color = self._bg_color_hover
            self._set_icon_color = self._icon_color_hover
            self.repaint()

    # 鼠标悬停
    # 当鼠标位于BTN上时触发的事件
    def enterEvent(self, event):
        self.change_style(QEvent.Enter)
        self.move_tooltip()
        self._tooltip.show()

    # 鼠标离开
    # 鼠标离开BTN时触发的事件
    def leaveEvent(self, event):
        self.change_style(QEvent.Leave)
        self.move_tooltip()
        self._tooltip.hide()

    # 鼠标按压
    # 按下左键时触发的事件
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.change_style(QEvent.MouseButtonPress)
            self.setFocus()
            return self.clicked.emit()

    # 鼠标释放
    # 松开鼠标按钮后触发的事件
    def mouseReleaseEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.change_style(QEvent.MouseButtonRelease)
            return self.released.emit()

    # 用颜色绘制图标
    def icon_paint(self, qp, image, rect):
        icon = QPixmap(image)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)
        if self._is_active:
            painter.fillRect(icon.rect(), self._context_color)
        else:
            painter.fillRect(icon.rect(), self._set_icon_color)
        qp.drawPixmap(
            (rect.width() - icon.width()) / 2,
            (rect.height() - icon.height()) / 2,
            icon
        )
        painter.end()

    # 设置图标
    def set_icon(self, icon_path):
        self._set_icon_path = icon_path
        self.repaint()

    # 移动工具提示
    def move_tooltip(self):
        # 获取主窗口父窗口
        gp = self.mapToGlobal(QPoint(0, 0))

        # 设置小部件以获取位置
        # 返回小部件在应用程序中的绝对位置
        pos = self._parent.mapFromGlobal(gp)

        # 使用偏移调整工具提示位置
        pos_x = (pos.x() - self._tooltip.width()) + self.width() + 5
        pos_y = pos.y() + self._top_margin

        # 移动工具提示位置
        self._tooltip.move(pos_x, pos_y)


# TOOLTIP

class _ToolTip(QLabel):
    style_tooltip = """ 
    QLabel {{		
        background-color: {_dark_one};	
        color: {_text_foreground};
        padding-left: 10px;
        padding-right: 10px;
        border-radius: 17px;
        border: 0px solid transparent;
        border-right: 3px solid {_context_color};
        font: 800 9pt "Segoe UI";
    }}
    """

    def __init__(
            self,
            parent,
            tooltip,
            dark_one,
            context_color,
            text_foreground
    ):
        QLabel.__init__(self)

        style = self.style_tooltip.format(
            _dark_one=dark_one,
            _context_color=context_color,
            _text_foreground=text_foreground
        )
        self.setObjectName(u"label_tooltip")
        self.setStyleSheet(style)
        self.setMinimumHeight(34)
        self.setParent(parent)
        self.setText(tooltip)
        self.adjustSize()

        # 设置阴影
        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(30)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 80))
        self.setGraphicsEffect(self.shadow)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoIcon(QWidget):
    def __init__(
            self,
            icon_path,
            icon_color
    ):
        super().__init__()

        self._icon_path = icon_path
        self._icon_color = icon_color

        self.setup_ui()

    def setup_ui(self):
        self.layout = QVBoxLayout(self)
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.icon = QLabel()
        self.icon.setAlignment(Qt.AlignCenter)
        self.set_icon(self._icon_path, self._icon_color)
        self.layout.addWidget(self.icon)

    def set_icon(self, icon_path, icon_color=None):
        color = ""
        if icon_color != None:
            color = icon_color
        else:
            color = self._icon_color

        # 画家/位图
        icon = QPixmap(icon_path)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)
        painter.fillRect(icon.rect(), color)
        painter.end()

        # 设置位图
        self.icon.setPixmap(icon)



from mango_ui.init import *
from mango_ui.models.models import TableColumnModel, TableMenuItemModel
from mango_ui.widgets import *


class TableList(QWidget):
    clicked = Signal(object)
    released = Signal(object)

    def __init__(self, row_column: list[TableColumnModel], row_ope: list[TableMenuItemModel] = None):
        super().__init__()
        self.row_column = row_column
        self.row_ope = row_ope
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.setSpacing(0)
        self.table_widget = MangoTableWidget(row_column, row_ope, )
        self.table_widget.clicked.connect(self.but_clicked)
        self.layout.addWidget(self.table_widget)
        self.pagination = MangoPagination(self)
        self.layout.addWidget(self.pagination)
        self.setLayout(self.layout)
        self.page_size = 10

    def set_data(self, data, total_size: int | None = None):
        if total_size:
            self.pagination.set_total_size(str(total_size))
        self.table_widget.set_value(data)

    def but_clicked(self, data):
        self.clicked.emit(data)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 显示（通知）
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏
from .mango_circular_progress import MangoCircularProgress
from .mango_label import MangoLabel
from .mango_message import MangoMessage
from .mango_notification import MangoNotification
from .mango_pagination import MangoPagination
from .mango_table_widget import MangoTableWidget



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-24 17:16
# @Author : 毛鹏
from mango_ui.init import *


class MangoCheckBox(QCheckBox):
    def __init__(self, text=None, parent=None):
        """
        构造函数，初始化复选框并设置文本和样式表。

        参数：
        - text：复选框显示的文本内容。
        """
        super().__init__(parent)
        self.setText(text)

    def isChecked(self):
        """
        判断复选框是否被选中。

        返回值：
        - 如果复选框被选中，返回 True；否则返回 False。
        """
        return super().isChecked()

    def setChecked(self, checked):
        """
        设置复选框的选中状态。

        参数：
        - checked：布尔值，True 表示选中，False 表示未选中。
        """
        super().setChecked(checked)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import os

from PySide6.QtCore import QRect, QEvent, QPoint
from PySide6.QtGui import QColor, Qt, QPainter, QPixmap
from PySide6.QtWidgets import QGraphicsDropShadowEffect, QLabel, QPushButton

from mango_ui.settings.settings import THEME


class MangoLeftMenuButton(QPushButton):
    def __init__(
            self,
            app_parent,
            text,
            btn_id=None,
            tooltip_text="",
            margin=4,
            dark_one=THEME.dark_one,
            dark_three=THEME.dark_three,
            dark_four=THEME.dark_four,
            bg_one=THEME.bg_one,
            icon_color=THEME.icon_color,
            icon_color_hover=THEME.icon_hover,
            icon_color_pressed=THEME.icon_pressed,
            icon_color_active=THEME.icon_active,
            context_color=THEME.context_color,
            text_foreground=THEME.text_foreground,
            text_active=THEME.text_active,
            icon_path=":/icons/icon_add_user.svg",
            icon_active_menu=":/icons/active_menu.svg",
            is_active=False,
            is_active_tab=False,
            is_toggle_active=False
    ):
        super().__init__()
        self.setText(text)
        self.setCursor(Qt.PointingHandCursor)
        self.setMaximumHeight(50)
        self.setMinimumHeight(50)
        self.setObjectName(btn_id)

        self._icon_path = icon_path
        self._icon_active_menu = icon_active_menu

        self._margin = margin
        self._dark_one = dark_one
        self._dark_three = dark_three
        self._dark_four = dark_four
        self._bg_one = bg_one
        self._context_color = context_color
        self._icon_color = icon_color
        self._icon_color_hover = icon_color_hover
        self._icon_color_pressed = icon_color_pressed
        self._icon_color_active = icon_color_active
        self._set_icon_color = self._icon_color
        self._set_bg_color = self._dark_one
        self._set_text_foreground = text_foreground
        self._set_text_active = text_active
        self._parent = app_parent
        self._is_active = is_active
        self._is_active_tab = is_active_tab
        self._is_toggle_active = is_toggle_active

        # 工具提示
        self._tooltip_text = tooltip_text
        self.tooltip = _ToolTip(
            app_parent,
            tooltip_text,
            dark_one,
            context_color,
            text_foreground
        )
        self.tooltip.hide()

    # PAINT EVENT

    def paintEvent(self, event):
        # PAINTER
        p = QPainter()
        p.begin(self)
        p.setRenderHint(QPainter.Antialiasing)
        p.setPen(Qt.NoPen)
        p.setFont(self.font())

        # RECTANGLES
        rect = QRect(4, 5, self.width(), self.height() - 10)
        rect_inside = QRect(4, 5, self.width() - 8, self.height() - 10)
        rect_icon = QRect(0, 0, 50, self.height())
        rect_blue = QRect(4, 5, 20, self.height() - 10)
        rect_inside_active = QRect(7, 5, self.width(), self.height() - 10)
        rect_text = QRect(45, 0, self.width() - 50, self.height())

        if self._is_active:
            # DRAW BG BLUE
            p.setBrush(QColor(self._context_color))
            p.drawRoundedRect(rect_blue, 8, 8)

            # BG INSIDE
            p.setBrush(QColor(self._bg_one))
            p.drawRoundedRect(rect_inside_active, 8, 8)

            # DRAW ACTIVE
            icon_path = self._icon_active_menu
            app_path = os.path.abspath(os.getcwd())
            icon_path = os.path.normpath(os.path.join(app_path, icon_path))
            self._set_icon_color = self._icon_color_active
            self.icon_active(p, icon_path, self.width())

            # DRAW TEXT
            p.setPen(QColor(self._set_text_active))
            p.drawText(rect_text, Qt.AlignVCenter, self.text())

            # DRAW ICONS
            self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)

        elif self._is_active_tab:
            # DRAW BG BLUE
            p.setBrush(QColor(self._dark_four))
            p.drawRoundedRect(rect_blue, 8, 8)

            # BG INSIDE
            p.setBrush(QColor(self._bg_one))
            p.drawRoundedRect(rect_inside_active, 8, 8)

            # DRAW ACTIVE
            icon_path = self._icon_active_menu
            app_path = os.path.abspath(os.getcwd())
            icon_path = os.path.normpath(os.path.join(app_path, icon_path))
            self._set_icon_color = self._icon_color_active
            self.icon_active(p, icon_path, self.width())

            # DRAW TEXT
            p.setPen(QColor(self._set_text_active))
            p.drawText(rect_text, Qt.AlignVCenter, self.text())

            # DRAW ICONS
            self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)

        # NORMAL BG
        else:
            if self._is_toggle_active:
                # BG INSIDE
                p.setBrush(QColor(self._dark_three))
                p.drawRoundedRect(rect_inside, 8, 8)

                # DRAW TEXT
                p.setPen(QColor(self._set_text_foreground))
                p.drawText(rect_text, Qt.AlignVCenter, self.text())

                # DRAW ICONS
                if self._is_toggle_active:
                    self.icon_paint(p, self._icon_path, rect_icon, self._context_color)
                else:
                    self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)
            else:
                # BG INSIDE
                p.setBrush(QColor(self._set_bg_color))
                p.drawRoundedRect(rect_inside, 8, 8)

                # DRAW TEXT
                p.setPen(QColor(self._set_text_foreground))
                p.drawText(rect_text, Qt.AlignVCenter, self.text())

                # DRAW ICONS
                self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)

        p.end()

    # SET ACTIVE MENU

    def set_active(self, is_active):
        self._is_active = is_active
        if not is_active:
            self._set_icon_color = self._icon_color
            self._set_bg_color = self._dark_one

        self.repaint()

    # SET ACTIVE TAB MENU

    def set_active_tab(self, is_active):
        self._is_active_tab = is_active
        if not is_active:
            self._set_icon_color = self._icon_color
            self._set_bg_color = self._dark_one

        self.repaint()

    # 如果是活动菜单，则返回
    def is_active(self):
        return self._is_active

    # 如果选项卡菜单处于活动状态，则返回
    def is_active_tab(self):
        return self._is_active_tab

    # 设置活动切换
    def set_active_toggle(self, is_active):
        self._is_toggle_active = is_active

    # 设置图标
    def set_icon(self, icon_path):
        self._icon_path = icon_path
        self.repaint()

    # 用颜色绘制图标
    def icon_paint(self, qp, image, rect, color):
        icon = QPixmap(image)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)
        painter.fillRect(icon.rect(), color)
        qp.drawPixmap(
            (rect.width() - icon.width()) / 2,
            (rect.height() - icon.height()) / 2,
            icon
        )
        painter.end()

    # 在右侧绘制活动图标
    def icon_active(self, qp, image, width):
        icon = QPixmap(image)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)
        painter.fillRect(icon.rect(), self._bg_one)
        qp.drawPixmap(width - 5, 0, icon)
        painter.end()

    # 更改样式
    def change_style(self, event):
        if event == QEvent.Enter:
            if not self._is_active:
                self._set_icon_color = self._icon_color_hover
                self._set_bg_color = self._dark_three
            self.repaint()
        elif event == QEvent.Leave:
            if not self._is_active:
                self._set_icon_color = self._icon_color
                self._set_bg_color = self._dark_one
            self.repaint()
        elif event == QEvent.MouseButtonPress:
            if not self._is_active:
                self._set_icon_color = self._context_color
                self._set_bg_color = self._dark_four
            self.repaint()
        elif event == QEvent.MouseButtonRelease:
            if not self._is_active:
                self._set_icon_color = self._icon_color_hover
                self._set_bg_color = self._dark_three
            self.repaint()

    # 当鼠标位于BTN上时触发的事件
    def enterEvent(self, event):
        self.change_style(QEvent.Enter)
        if self.width() == 50 and self._tooltip_text:
            self.move_tooltip()
            self.tooltip.show()

    # 鼠标离开BTN时触发的事件
    def leaveEvent(self, event):
        self.change_style(QEvent.Leave)
        self.tooltip.hide()

    # 按下左键时触发的事件
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.change_style(QEvent.MouseButtonPress)
            self.tooltip.hide()
            return self.clicked.emit()

    # 松开鼠标按钮后触发的事件
    def mouseReleaseEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.change_style(QEvent.MouseButtonRelease)
            return self.released.emit()

    def move_tooltip(self):
        gp = self.mapToGlobal(QPoint(0, 0))

        pos = self._parent.mapFromGlobal(gp)

        pos_x = pos.x() + self.width() + 5
        pos_y = pos.y() + (self.width() - self.tooltip.height()) // 2

        self.tooltip.move(pos_x, pos_y)


class _ToolTip(QLabel):
    style_tooltip = """ 
    QLabel {{		
        background-color: {_dark_one};	
        color: {_text_foreground};
        padding-left: 10px;
        padding-right: 10px;
        border-radius: 17px;
        border: 0px solid transparent;
        border-left: 3px solid {_context_color};
        font: 800 9pt "Segoe UI";
    }}
    """

    def __init__(
            self,
            parent,
            tooltip,
            dark_one,
            context_color,
            text_foreground
    ):
        QLabel.__init__(self)

        style = self.style_tooltip.format(
            _dark_one=dark_one,
            _context_color=context_color,
            _text_foreground=text_foreground
        )
        self.setObjectName(u"label_tooltip")
        self.setStyleSheet(style)
        self.setMinimumHeight(34)
        self.setParent(parent)
        self.setText(tooltip)
        self.adjustSize()

        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(30)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 80))
        self.setGraphicsEffect(self.shadow)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-29 15:32
# @Author : 毛鹏
from .diglog_widget import DialogWidget
from .message import info_message, error_message, success_message, warning_message, response_message
from .methods import *
from .notification import info_notification, error_notification, success_notification, warning_notification
from .right_button import RightButton
from .search_widget import SearchWidget
from .table_list import TableList
from .title_info import TitleInfoWidget



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from .charts import *
from .container import *
from .display import *
from .graphics import *
from .input import *
from .layout import *
from .menu import *
from .miscellaneous import *
from .title_bar import *
from .window import *



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import json
from functools import partial

from mango_ui.init import *
from mango_ui.models.models import TableColumnModel, TableMenuItemModel


class MangoTableWidget(QTableWidget):
    clicked = Signal(object)

    def __init__(self, row_column: list[TableColumnModel], row_ope: list[TableMenuItemModel] = None, theme=THEME, ):
        super().__init__()
        self.row_column = row_column
        self.row_ope = row_ope
        self.column_count = len(row_column)
        self.header_labels = [i.name for i in row_column]
        self.theme = theme.model_dump()
        self.set_stylesheet(self.theme)
        self.setColumnCount(self.column_count)
        self.setHorizontalHeaderLabels(self.header_labels)

        self.set_column_widths()
        self.setSelectionMode(QAbstractItemView.ExtendedSelection)
        self.setSelectionBehavior(QAbstractItemView.SelectRows)
        self.verticalHeader().setVisible(False)

        self.setEditTriggers(QTableWidget.NoEditTriggers)

    def set_column_widths(self):
        for index, column in enumerate(self.row_column):
            if column.width:
                self.setColumnWidth(index, column.width)
                self.horizontalHeader().setSectionResizeMode(index, QHeaderView.Fixed)
            else:
                self.horizontalHeader().setSectionResizeMode(index, QHeaderView.Stretch)

    def set_value(self, data):
        self.setRowCount(0)
        if data is None:
            return

        for row, item in enumerate(data):
            self.insertRow(row)
            for row1, column in enumerate(self.row_column):
                if column.key != 'ope':
                    if isinstance(item[column.key], dict):
                        item1 = item[column.key].get('name', json.dumps(item[column.key]))
                    else:
                        item1 = item[column.key]
                    if column.option is not None:
                        item1 = self.get_option_value(column.option, item1)
                    # 设置单元格内容
                    cell_item = QTableWidgetItem(str(item1))
                    self.setItem(row, row1, cell_item)

            if self.row_ope:
                action_widget = QWidget()
                action_layout = QHBoxLayout()
                action_widget.setLayout(action_layout)
                for ope in self.row_ope:
                    but = QPushButton(ope.name)
                    but.setStyleSheet(
                        'QPushButton { background-color: transparent; border: none; padding: 0; color: blue; font-size: 10px; }')
                    but.setCursor(QCursor(Qt.PointingHandCursor))
                    action_layout.addWidget(but)
                    if not ope.son:
                        but.clicked.connect(partial(self.but_clicked, {'action': ope.action, 'row': item}))
                    else:
                        menu = QMenu()
                        for ope1 in ope.son:
                            action = QAction(ope1.name, self)
                            action.triggered.connect(partial(self.but_clicked, {'action': ope1.action, 'row': item}))
                            menu.addAction(action)
                        but.clicked.connect(lambda _, m=menu: m.exec_(QCursor.pos()))

                self.setCellWidget(row, len(self.row_column) - 1, action_widget)

    def get_option_value(self, option: list[dict], item1) -> str:
        for i in option:
            if i.get('children'):
                for e in i.get('children'):
                    if e.get('children'):
                        for q in e.get('children'):
                            if q.get('value') == item1:
                                return q.get('label')
                    else:
                        if e.get('value') == item1:
                            return e.get('label')
            if i.get('value') == item1:
                return i.get('label')

    def but_clicked(self, data):
        self.clicked.emit(data)

    def set_stylesheet(self, theme):
        style = f'''
        /* 
        QTableWidget */

        QTableWidget {{	
        	background-color: {theme['dark_three']};
        	padding: 5px;
        	border-radius: {theme['radius']}px;
        	gridline-color: {theme['bg_three']};
            color: {theme['text_foreground']};
        }}
        QTableWidget::item{{
        	border-color: none;
        	padding-left: 5px;
        	padding-right: 5px;
        	gridline-color: rgb(44, 49, 60);
            border-bottom: 1px solid {theme['dark_two']};
        }}
        QTableWidget::item:selected{{
        	background-color: {theme['context_hover']};
        }}
        QHeaderView::section{{
        	background-color: rgb(33, 37, 43);
        	max-width: 30px;
        	border: 1px solid rgb(44, 49, 58);
        	border-style: none;
            border-bottom: 1px solid rgb(44, 49, 60);
            border-right: 1px solid rgb(44, 49, 60);
        }}
        QTableWidget::horizontalHeader {{	
        	background-color: rgb(33, 37, 43);
        }}
        QTableWidget QTableCornerButton::section {{
            border: none;
        	background-color: {theme['bg_three']};
        	padding: 3px;
            border-top-left-radius: {theme['radius']}px;
        }}
        QHeaderView::section:horizontal
        {{
            border: none;
        	background-color: {theme['dark_two']};
        	padding: 3px;
        }}
        QHeaderView::section:vertical
        {{
            border: none;
        	background-color: {theme['bg_three']};
        	padding-left: 5px;
            padding-right: 5px;
            border-bottom: 1px solid {theme['bg_three']};
            margin-bottom: 1px;
        }}


        /* 
        ScrollBars */
        QScrollBar:horizontal {{
            border: none;
            background: {theme['bg_one']};
            height: 8px;
            margin: 0px 21px 0 21px;
        	border-radius: 0px;
        }}
        QScrollBar::handle:horizontal {{
            background: {theme['context_hover']};
            min-width: 25px;
        	border-radius: 4px
        }}
        QScrollBar::add-line:horizontal {{
            border: none;
            background: {theme['dark_four']};
            width: 20px;
        	border-top-right-radius: 4px;
            border-bottom-right-radius: 4px;
            subcontrol-position: right;
            subcontrol-origin: margin;
        }}
        QScrollBar::sub-line:horizontal {{
            border: none;
            background: {theme['dark_four']};
            width: 20px;
        	border-top-left-radius: 4px;
            border-bottom-left-radius: 4px;
            subcontrol-position: left;
            subcontrol-origin: margin;
        }}
        QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal
        {{
             background: none;
        }}
        QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal
        {{
             background: none;
        }}
        QScrollBar:vertical {{
        	border: none;
            background: {theme['bg_one']};
            width: 8px;
            margin: 21px 0 21px 0;
        	border-radius: 0px;
        }}
        QScrollBar::handle:vertical {{	
        	background: {theme['context_hover']};
            min-height: 25px;
        	border-radius: 4px
        }}
        QScrollBar::add-line:vertical {{
             border: none;
            background: {theme['dark_four']};
             height: 20px;
        	border-bottom-left-radius: 4px;
            border-bottom-right-radius: 4px;
             subcontrol-position: bottom;
             subcontrol-origin: margin;
        }}
        QScrollBar::sub-line:vertical {{
        	border: none;
            background: {theme['dark_four']};
             height: 20px;
        	border-top-left-radius: 4px;
            border-top-right-radius: 4px;
             subcontrol-position: top;
             subcontrol-origin: margin;
        }}
        QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {{
             background: none;
        }}

        QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {{
             background: none;
        }}
        '''
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-08 9:56
# @Author : 毛鹏
from mango_ui.components import error_message
from mango_ui.models.models import DialogCallbackModel, ComboBoxDataModel
from mango_ui.settings import settings


def set_product_module(parent, data: DialogCallbackModel) -> list[ComboBoxDataModel]:
    for e in settings.base_dict:
        for q in e.children:
            if q.value == data.value:
                init_data = []
                for i in q.children:
                    init_data.append(ComboBoxDataModel(id=i.value, name=i.label))
                if init_data == {}:
                    error_message(parent, '您选择的项目还没创建模块，请先创建模块！')
                return init_data


def get_product_module_label(product_id: int):
    for e in settings.base_dict:
        for q in e.children:
            if q.value == product_id:
                return q.children



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-19 11:29
# @Author : 毛鹏
from mango_ui.init import *


class MangoCardWidget(QWidget):
    def __init__(self, layout, title: str | None = None, background_color=THEME.dark_three, parent=None):
        super().__init__(parent)
        self.background_color = background_color
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)

        self.frame = QFrame()
        if title:
            self.frame_layout = QVBoxLayout()
            self.frame_layout.setContentsMargins(0, 0, 0, 0)
            self.frame.setLayout(self.frame_layout)
            title_label = QLabel(title)
            font = QFont()
            font.setPointSize(18)  # 设置字体大小
            font.setBold(True)  # 设置为粗体
            title_label.setFont(font)
            self.frame_layout.addWidget(title_label)
            self.frame.setLayout(self.frame_layout)
            self.frame_layout_h = QHBoxLayout()
            self.frame_layout_h.setContentsMargins(10, 0, 0, 0)
            self.frame_layout_h.addLayout(layout)
            self.frame_layout.addLayout(self.frame_layout_h)
        else:
            self.frame.setLayout(layout)
        self.layout.addWidget(self.frame)

        self.setLayout(self.layout)
        self.set_stylesheet()

    def set_stylesheet(self):
        self.setObjectName('mangoCard')
        style = f"""
        QWidget#mangoCard {{
            background-color: {self.background_color};
            border: 1px solid {self.background_color};
            border-radius: {THEME.radius}px;
            padding: 10px;
        }}
        QWidget#mangoCard > QFrame {{
            background-color: {self.background_color};
            border: 1px solid {self.background_color};
            border-radius: {THEME.radius}px;
            padding: 10px;
        }}

        """
        # QWidget#mangoCard QLabel {{
        #     border: none;
        #     margin-top: 0;
        #     margin-bottom: 0;
        #     margin-left: 0;
        #     margin-right: 5;
        #     padding-top: 0;
        #     padding-bottom: 0;
        #     padding-left: 0;
        #     padding-right: 0;
        # }}
        self.setStyleSheet(style)



import sys

from PySide6.QtCore import Qt
from PySide6.QtGui import QFont
from PySide6.QtWidgets import QComboBox, QMainWindow, QApplication, QToolTip, QLineEdit


class CheckablerComboBox(QComboBox):
    def __init__(self, parent=None):
        super(CheckableComboBox, self).__init__(parent)
        QToolTip.setFont(QFont('Times New Roman', 15))  # 设置提示框字体和字号
        self.setLineEdit(QLineEdit())
        self.lineEdit().setReadOnly(True)
        self.view().clicked.connect(self.selectItemAction)
        self.addCheckableItem('全选')
        self.SelectAllStatus = 1

    def addCheckableItem(self, text):
        super().addItem(text)
        item = self.model().item(self.count() - 1, 0)
        item.setFlags(Qt.ItemFlag.ItemIsUserCheckable | Qt.ItemFlag.ItemIsEnabled)
        item.setCheckState(Qt.CheckState.Unchecked)
        item.setToolTip(text)

    def addCheckableItems(self, texts):
        for text in texts:
            self.addCheckableItem(text)

    def ifChecked(self, index):
        item = self.model().item(index, 0)
        return item.checkState() == Qt.CheckState.Checked

    def checkedItems(self):
        return [self.itemText(i) for i in range(self.count()) if self.ifChecked(i)]

    def checkedItemsStr(self):
        return ';'.join(self.checkedItems()).strip('全选').strip(';')

    def showPopup(self):
        self.view().setMinimumWidth(3 * self.width() // 2)  # 下拉列表宽度加大
        self.view().setMaximumHeight(200)  # 最大高度为200
        super().showPopup()

    def selectItemAction(self, index):
        if index.row() == 0:
            for i in range(self.model().rowCount()):
                if self.SelectAllStatus:
                    self.model().item(i).setCheckState(Qt.CheckState.Checked)
                else:
                    self.model().item(i).setCheckState(Qt.CheckState.Unchecked)
            self.SelectAllStatus = (self.SelectAllStatus + 1) % 2

        self.lineEdit().clear()
        self.lineEdit().setText(self.checkedItemsStr())

    def clear(self) -> None:
        super().clear()
        self.addCheckableItem('全选')

    def select_all(self):
        for i in range(self.model().rowCount()):
            self.model().item(i).setCheckState(Qt.CheckState.Checked)
        self.lineEdit().setText(self.checkedItemsStr())


class Ui_Study(QMainWindow):
    def __init__(self):
        super().__init__()
        self.resize(500, 500)
        self.setMinimumSize(500, 500)

        self.combobox = CheckableComboBox(self)
        self.combobox.move(20, 20)
        self.combobox.resize(200, 30)

        self.line_edit = QLineEdit(self)
        self.line_edit.move(20, 80)
        self.line_edit.resize(300, 30)

        self.combobox.addCheckableItems(['sdsfdsf', 'hgjghj', 'reyeyey'])
        self.combobox.setCurrentIndex(-1)
        self.combobox.lineEdit().textChanged.connect(lambda: self.line_edit.setText(self.combobox.checkedItemsStr()))

        self.show()


if __name__ == '__main__':
    app = QApplication(sys.argv)
    my_ui = Ui_Study()
    a = my_ui.combobox
    sys.exit(app.exec())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoDiv(QWidget):
    def __init__(self, color):
        super().__init__()
        self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(5, 0, 5, 0)

        self.frame_line = QFrame()
        self.frame_line.setStyleSheet(f"background: {color};")

        self.frame_line.setMaximumHeight(1)
        self.frame_line.setMinimumHeight(1)
        self.layout.addWidget(self.frame_line)
        self.setMaximumHeight(0)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoPushButton(QPushButton):
    def __init__(
            self,
            text,
            theme=THEME,
            parent=None,
            **kwargs
    ):
        super().__init__()
        self.setText(text)
        self.theme = theme
        self.kwargs = kwargs
        if parent:
            self.setParent(parent)

        self.set_stylesheet()
        self.setCursor(Qt.PointingHandCursor)

    def set_stylesheet(self, height=35, width=60):
        style = f'''
        QPushButton {{
            border: 1px solid {self.theme.dark_four};
            color: {self.theme.text_foreground};
            border-radius: {self.theme.radius};	
            background-color: {self.kwargs.get('color') if self.kwargs.get('color') else self.theme.dark_one};
        }}
        QPushButton:hover {{
            background-color: {self.theme.dark_three};
        }}
        QPushButton:pressed {{	
            background-color: {self.theme.dark_four};
        }}
        '''
        self.setStyleSheet(style)
        self.setMinimumHeight(height)
        self.setMinimumWidth(width)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
from mango_ui.init import *
from mango_ui.models.models import SearchDataModel
from mango_ui.widgets import *


class SearchWidget(QWidget):
    clicked = Signal(object)

    def __init__(self, search_data: list[SearchDataModel]):
        super().__init__()
        self.search_data = search_data
        self.layout = QHBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.setLayout(self.layout)

        self.v_layout = QVBoxLayout()
        self.v_layout.setContentsMargins(0, 0, 0, 0)
        self.layout.addLayout(self.v_layout)
        for index, search in enumerate(self.search_data):
            if index % 4 == 0 or index == 0:
                but_layout = QHBoxLayout()
                but_layout.setContentsMargins(0, 0, 0, 0)
                self.v_layout.addLayout(but_layout)
            from_layout = QFormLayout()
            intput = MangoLineEdit(search.placeholder, '', )
            from_layout.addRow(f'{search.title}：', intput)
            but_layout.addLayout(from_layout)
            search.input = intput
            if (index + 1) % 4 == 0 or index == len(self.search_data) - 1:
                if (index + 1) % 4 != 0:
                    but_layout.addStretch()

        self.layout.addStretch()
        self.search_but = MangoPushButton('搜索', color=THEME.blue)
        self.search_but.setMinimumHeight(30)  # 设置最小高度
        self.search_but.setMinimumWidth(50)
        self.search_but.clicked.connect(self.on_search_but_clicked)

        self.layout.addWidget(self.search_but)

        self.reset_but = MangoPushButton('重置', color=THEME.red)
        self.reset_but.setMinimumHeight(30)  # 设置最小高度
        self.reset_but.setMinimumWidth(50)
        self.reset_but.clicked.connect(self.on_reset_but_clicked)
        self.layout.addWidget(self.reset_but)

        self.layout.addLayout(self.layout)

    def on_reset_but_clicked(self):
        for search in self.search_data:
            search.input.setText('')
        self.clicked.emit({})

    def on_search_but_clicked(self):
        data = {}
        for search in self.search_data:
            value = search.input.text()
            if value:
                data[search.key] = value
        self.clicked.emit(data)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
from mango_ui.models.models import FieldListModel
from mango_ui.widgets import *
from mango_ui.init import *


class TitleInfoWidget(QWidget):

    def __init__(self):
        super().__init__()
        self.field_list = None
        self.raw_data = None
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.form_layout = QFormLayout()
        self.mango_card = MangoCardWidget(self.form_layout)
        self.layout.addWidget(self.mango_card)
        self.setLayout(self.layout)

    def init(self, raw_data: dict, field_list: list[FieldListModel]):
        if self.field_list is None and self.raw_data is None:
            self.field_list = field_list
            self.raw_data = raw_data
            for i in self.field_list:
                self.form_layout.addRow(f"{i.name}：", MangoLabel(f'{self.raw_data[i.key]}'))



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:15
# @Author : 毛鹏
from typing import Any

from pydantic import BaseModel


class ResponseModel(BaseModel):
    code: int
    msg: str
    data: list[dict] | dict | None = None
    totalSize: int | None = None


class Font(BaseModel):
    family: str
    title_size: int
    text_size: int


class LeftMenuSize(BaseModel):
    minimum: int
    maximum: int


class ColumnSize(BaseModel):
    minimum: int
    maximum: int


class AppConfig(BaseModel):
    app_name: str
    version: str
    copyright: str
    year: int
    theme_name: str
    custom_title_bar: bool
    startup_size: list[int]
    minimum_size: list[int]
    lef_menu_size: LeftMenuSize
    left_menu_content_margins: int
    left_column_size: ColumnSize
    right_column_size: ColumnSize
    time_animation: int
    font: Font


class ThemeConfig(BaseModel):
    theme_name: str
    dark_one: str
    dark_two: str
    dark_three: str
    dark_four: str
    bg_one: str
    bg_two: str
    bg_three: str
    icon_color: str
    icon_hover: str
    icon_pressed: str
    icon_active: str
    context_color: str
    context_hover: str
    context_pressed: str
    text_title: str
    text_foreground: str
    text_description: str
    text_active: str
    white: str
    pink: str
    green: str
    red: str
    yellow: str
    blue: str
    orange: str
    radius: str
    border_size: str
    font: Font


class LeftMenuModel(BaseModel):
    btn_icon: str
    btn_id: str
    btn_text: str
    btn_tooltip: str
    show_top: bool
    is_active: bool
    is_active: bool
    submenus: list['LeftMenuModel'] = []


class TitleBarMenusModel(BaseModel):
    btn_icon: str
    btn_id: str
    btn_tooltip: str
    is_active: bool


class MenusModel(BaseModel):
    left_menus: list[LeftMenuModel]
    title_bar_menus: list[TitleBarMenusModel]


class SearchDataModel(BaseModel):
    title: str
    placeholder: str
    key: str
    input: None = None
    # input: MangoLineEdit | None = None


class RightDataModel(BaseModel):
    name: str
    theme: str
    action: str


class FormDataModel(BaseModel):
    title: str
    placeholder: str
    key: str
    input_object: None = None
    # input: MangoLineEdit | None = None
    value: str | None = None
    type: Any = 0
    select: dict | list[dict] | Any = None  # 选项数据
    subordinate: str | None = None  # 是否联动下级选择条件
    required: bool = True  # 是否必填


class TableColumnModel(BaseModel):
    key: str
    name: str
    width: int | None = None
    option: dict | list[dict] | None = None


class TableMenuItemModel(BaseModel):
    name: str
    action: str
    son: list['TableMenuItemModel'] = []


class FieldListModel(BaseModel):
    key: str
    name: str


class CascaderModel(BaseModel):
    value: int | str
    label: str
    children: list['CascaderModel'] = []


class DialogCallbackModel(BaseModel):
    key: str | None = None
    value: int | str | None
    input_object: Any | None = None
    subordinate: str
    subordinate_input_object: Any | None = None


class ComboBoxDataModel(BaseModel):
    id: int | None
    name: str | None



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoCredits(QWidget):
    def __init__(
            self,
            copyright,
            version,
            bg_two,
            font_family,
            text_size,
            text_description_color,
            radius=8,
            padding=10
    ):
        super().__init__()

        self._copyright = copyright
        self._version = version
        self._bg_two = bg_two
        self._font_family = font_family
        self._text_size = text_size
        self._text_description_color = text_description_color
        self._radius = radius
        self._padding = padding

        self.setup_ui()

    def setup_ui(self):
        self.widget_layout = QHBoxLayout(self)
        self.widget_layout.setContentsMargins(0, 0, 0, 0)

        # BG STYLE
        style = f"""
        #bg_frame {{
            border-radius: {self._radius}px;
            background-color: {self._bg_two};
        }}
        .QLabel {{
            font: {self._text_size}pt "{self._font_family}";
            color: {self._text_description_color};
            padding-left: {self._padding}px;
            padding-right: {self._padding}px;
        }}
        """

        self.bg_frame = QFrame()
        self.bg_frame.setObjectName("bg_frame")
        self.bg_frame.setStyleSheet(style)

        self.widget_layout.addWidget(self.bg_frame)

        self.bg_layout = QHBoxLayout(self.bg_frame)
        self.bg_layout.setContentsMargins(0, 0, 0, 0)

        self.copyright_label = QLabel(self._copyright)
        self.copyright_label.setAlignment(Qt.AlignVCenter)

        self.version_label = QLabel(self._version)
        self.version_label.setAlignment(Qt.AlignVCenter)

        self.separator = QSpacerItem(20, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.bg_layout.addWidget(self.copyright_label)
        self.bg_layout.addSpacerItem(self.separator)
        self.bg_layout.addWidget(self.version_label)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-04 17:43
# @Author : 毛鹏
from PySide6.QtWidgets import QWidget, QVBoxLayout, QApplication, QPushButton, QFrame, QFormLayout, QLabel

from mango_ui.settings.settings import THEME


class Card(QFrame):
    def __init__(self, layout, background_color=THEME.pink, parent=None):
        super().__init__(parent)
        self.background_color = background_color
        self.layout = QVBoxLayout()
        self.widget = QWidget()
        self.widget.setParent(None)
        self.widget.setStyleSheet("QWidget { background-color: transparent; border: none; }")
        self.widget.setLayout(layout)
        self.layout.addWidget(self.widget)
        self.setLayout(self.layout)
        self.setFrameShape(QFrame.StyledPanel)  # 设置边框样式
        self.setFrameShadow(QFrame.Raised)  # 设置阴影样式
        self.setLineWidth(1)  # 设置边框宽度
        self.set_stylesheet()

    def set_stylesheet(self):
        style = f"""
        QFrame {{
            background-color: {self.background_color};
            border: 1px solid #d0d0d0;
            border-radius: 8px;
            padding: 10px;
        }}

        """

        self.setStyleSheet(style)


class MyQWidget(QWidget):

    def __init__(self):
        super().__init__()
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.setSpacing(0)  # 设置间距为0
        self.resize(800, 400)
        self.layout_1 = QFormLayout()
        self.layout_1.addWidget(QPushButton('1'))
        self.layout_1.addWidget(QLabel('哈哈哈'))
        self.widget = Card(self.layout_1)
        self.layout.addWidget(self.widget)
        self.layout.addWidget(QPushButton('2'))
        self.setLayout(self.layout)


if __name__ == '__main__':
    app = QApplication([])
    window = MyQWidget()
    window.show()
    app.exec()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 输入
# @Time   : 2024-09-12 10:51
# @Author : 毛鹏
from .mango_cascader import MangoCascade
from .mango_checkbox import MangoCheckBox
from .mango_combo_box import MangoComboBox
from .mango_icon_button import MangoIconButton
from .mango_line_edit import MangoLineEdit
from .mango_push_button import MangoPushButton
from .mango_slider import MangoSlider
from .mango_text_edit import MangoTextEdit
from .mango_toggle import MangoToggle



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-01 下午9:53
# @Author : 毛鹏
from mango_ui.init import *


class MangoNotification(QWidget):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint | Qt.Tool)
        self.setFixedSize(210, 70)

        layout = QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        self.label = QLabel(message)
        layout.addWidget(self.label)

        self.setLayout(layout)

        # 设置微红色背景色
        self.setStyleSheet(f"background-color: {style}; opacity: 0.39;")

        # 设置渐隐效果
        self.opacity = 1.0
        self.timer = QTimer(self)
        self.timer.timeout.connect(self.fade_out)
        self.timer.start(80)

    def fade_out(self):
        self.opacity -= 0.05
        self.setWindowOpacity(self.opacity)
        if self.opacity <= 0:
            self.close()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:09
# @Author : 毛鹏
from .components import *
from .enums.enums import *
from .models.models import *
from .settings.settings import *
from .widgets import *



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-05-27 13:04
# @Author : 毛鹏


def show_failed_message(text: str, title: str = '失败'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Critical)
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.exec()


def show_success_message(text: str, title: str = '成功'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Information)
    msg.setWindowTitle(title)
    msg.setText(text)
    msg.exec()


def show_warning_message(text: str, title: str = '警告'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Warning)
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.exec()


def show_info_message(text: str, title: str = '提示'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Information)
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.exec()
